@@ -8,3 +8,6 @@ class CloudStackServiceofferingAdmin(admin.ModelAdmin):
     list_display = ("serviceofferingid", "name", "region", "cpus", "memory_size_mb")
     list_filter = ("region", )
     save_on_top = True
+
+    change_form_template = "dbaas_cloudstack/cloudstackoffering/change_form.html"
+    add_form_template = "admin/change_form.html"    
\ No newline at end of file
