@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
+import os
 import logging
 import simple_audit
 from dbaas_cloudstack.util.models import BaseModel
@@ -50,7 +51,9 @@ class HostAttr(BaseModel):
     vm_user = models.CharField(verbose_name=_("Cloud Stack virtual machine user"), max_length=255, blank=True, null=True)
     vm_password = EncryptedCharField(verbose_name=_("Cloud Stack virtual machine password"), max_length=255, blank=True, null=True)
     host = models.ForeignKey('physical.Host', related_name="cs_host_attributes")
-    bundle = models.ForeignKey(CloudStackBundle, null=True, blank=True)
+    bundle = models.ForeignKey(
+        CloudStackBundle, null=True, blank=True, on_delete=models.SET_NULL
+    )
 
     def __unicode__(self):
         return "Cloud Stack host Attributes (host=%s)" % (self.host)
@@ -134,23 +137,9 @@ class OfferingGroup(BaseModel):
 
 
 class PlanAttr(BaseModel):
-    serviceofferingid = models.ManyToManyField(CloudStackOffering)
     offering_group = models.ForeignKey(OfferingGroup, null=True, blank=True)
     plan = models.ForeignKey('physical.Plan', related_name="cs_plan_attributes")
-    bundle = models.ManyToManyField(CloudStackBundle)
     bundle_group = models.ForeignKey(BundleGroup, null=True, blank=True)
-    userdata = models.TextField(verbose_name=_("Initialization Script"),
-                                help_text="Script to create initialization files",
-                                null=False, blank=True)
-    configuration_script = models.TextField(verbose_name=_("Configuration Script"),
-                                            help_text="Script to configure database insatnces",
-                                            null=False, blank=True)
-    start_database_script = models.TextField(verbose_name=_("Start database Script"),
-                                             help_text="Script to start database instances",
-                                             null=False, blank=True)
-    start_replication_script = models.TextField(verbose_name=_("Start replication Script"),
-                                                help_text="Script to start database replication",
-                                                null=True, blank=True)
 
     @property
     def bundles(self):
@@ -191,10 +180,6 @@ class PlanAttr(BaseModel):
         )
         verbose_name_plural = "CloudStack Custom Plan Attributes"
 
-    @property
-    def initialization_script(self,):
-        return self.userdata
-
 
 class BundleModel(BaseModel):
 
@@ -264,7 +249,7 @@ class LastUsedBundleDatabaseInfra(BundleModel):
     @classmethod
     def get_next_infra_bundle(cls, databaseinfra):
         plan = PlanAttr.objects.get(plan=databaseinfra.plan)
-        bundles = list(plan.bundle.filter(is_active=True))
+        bundles = list(plan.bundles.filter(is_active=True))
         randon_bundle = bundles[cls.get_randon_bundle_index(bundles)]
 
         obj, created = cls.objects.get_or_create(
@@ -290,23 +275,32 @@ class LastUsedBundleDatabaseInfra(BundleModel):
 
 
 class CloudStackPack(BaseModel):
-    script = models.TextField(verbose_name=_("Script"), help_text="Script setup database")
     offering = models.ForeignKey('CloudStackOffering', related_name="cs_offering_packs")
     engine_type = models.ForeignKey('physical.EngineType', verbose_name=_("Engine Type"), related_name='cs_packs')
     name = models.CharField(verbose_name=_("Name"), max_length=100, help_text="Cloud Stack Pack Name")
+    script_file = models.CharField(
+        verbose_name=_("Script"), max_length=300, help_text="Full file path",
+        null=True, blank=True
+    )
 
     def __unicode__(self):
         return "%s" % (self.name)
 
+    @property
     def get_region(self):
         return self.offering.region
 
-    region = property(get_region)
-
+    @property
     def get_environment(self):
         return self.offering.region.environment
 
-    environment = property(get_environment)
+    @property
+    def script_template(self):
+        if not self.script_file:
+            return ""
+
+        with open(self.script_file) as f:
+            return f.read()
 
 
 simple_audit.register(PlanAttr)
